==> python-bale-bot-2.4.1.tar.gz: python-bale-bot-2.4.1/README.md <==
# python-bale-bot

<div align='center'>

<img width=200 src="https://python-bale-bot.readthedocs.io/en/master/_static/bale.png" alt="python-bale-bot image">
<br>
<b style='margin-bottom:20px;'>An API wrapper for Bale written in Python. </b>
<br>

[![Python Version](https://img.shields.io/badge/Python-3.8_|_3.9_|_3.10-red?logo=python&style=plastic)](https://pypi.org/p/python-bale-bot)
[![PyPi Version](https://img.shields.io/pypi/v/python-bale-bot?color=blue&label=pypi&style=plastic)](https://pypi.org/p/python-bale-bot)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/deacf2bc3f13492d944e329ac19ac0d1)](https://www.codacy.com/gh/python-bale-bot/python-bale-bot/dashboard)
[![Project License](https://img.shields.io/github/license/python-bale-bot/python-bale-bot?style=plastic)](https://opensource.org/licenses/MIT)
[![API Version](https://img.shields.io/badge/Bale%20API-1.0-blue?style=plastic)](https://dev.bale.ai/api)
[![Documentation Status](https://readthedocs.org/projects/python-telegram-bot/badge/?version=stable)](https://python-bale-bot.rtfd.org/)

</div>

## Installing
<div align='center'><p><b>You can install or update <code>python-bale-bot</code> via:</b></p></div>

### PyPi:

```
$ pip install python-bale-bot -U
```

### Git:

```
$ git clone https://github.com/python-bale-bot/python-bale-bot
$ cd python-bale-bot
$ python setup.py install
```

## Documentation
<p><b>The <a href="https://python-bale-bot.readthedocs.io/en/">package documentation</a> is the technical reference for python-bale-bot. It contains descriptions of all available classes, modules, methods and arguments as well as the changelog.</b></p>


## Contact to Developers
[![Email](https://img.shields.io/badge/Email-python--bale--bot@googlegroups.com-green?logo=Gmail&logoColor=white)](mailto:python-bale-bot@googlegroups.com)

==> python-bale-bot-2.4.3.tar.gz: python-bale-bot-2.4.3/README.md <==
# python-bale-bot

<div align='center'>

<img width=200 src="https://python-bale-bot.readthedocs.io/en/master/_static/bale.png" alt="python-bale-bot image">
<br>
<b style='margin-bottom:20px;'>An API wrapper for Bale written in Python. </b>
<br>

[![Python Version](https://img.shields.io/badge/Python-3.8_|_3.9_|_3.10_|_3.11_-red?logo=python&style=plastic)](https://pypi.org/p/python-bale-bot)
[![PyPi Version](https://img.shields.io/pypi/v/python-bale-bot?color=blue&label=pypi&style=plastic)](https://pypi.org/p/python-bale-bot)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/deacf2bc3f13492d944e329ac19ac0d1)](https://www.codacy.com/gh/python-bale-bot/python-bale-bot/dashboard)
[![Project License](https://img.shields.io/github/license/python-bale-bot/python-bale-bot?style=plastic)](https://opensource.org/licenses/MIT)
[![API Version](https://img.shields.io/badge/Bale%20API-1.0-blue?style=plastic)](https://dev.bale.ai/api)
[![Documentation Status](https://readthedocs.org/projects/python-telegram-bot/badge/?version=stable)](https://python-bale-bot.rtfd.org/)

</div>

## Installing
<div align='center'><p><b>You can install or update <code>python-bale-bot</code> via:</b></p></div>

### PyPi:

```
$ pip install python-bale-bot -U
```

### Git:

```
$ git clone https://github.com/python-bale-bot/python-bale-bot
$ cd python-bale-bot
$ python setup.py install
```

## Documentation
<p><b>The <a href="https://python-bale-bot.readthedocs.io/en/master">package documentation</a> is the technical reference for python-bale-bot. It contains descriptions of all available classes, modules, methods and arguments as well as the changelog.</b></p>


## Contact to Developers
[![Email](https://img.shields.io/badge/Email-python--bale--bot@googlegroups.com-green?logo=Gmail&logoColor=white)](mailto:python-bale-bot@googlegroups.com)
